<?php

namespace EventPortal\Domain\Venue\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Domain\Address\Models\Address;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Event\Models\EventVenue;
use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;
use Illuminate\Database\Eloquent\Relations\MorphOne;
use OwenIt\Auditing\Auditable;
use OwenIt\Auditing\Contracts\Auditable as AuditableInterface;

class Venue extends Model implements AuditableInterface
{
    use HasTable,
        AddToFillable,
        AddToCasts,
        Auditable;

    public const KEY = 'venue';

    /** @var array<string> */
    protected $fillable = [
        'name',
        'website',
        'star_rating',
        'has_green_tourism_accreditation',
        'how_to_get_there',
    ];

    /** @var array<string> */
    protected $casts = [
        'star_rating' => 'array',
        'has_green_tourism_accreditation' => 'boolean',
    ];

    /** @var array<string> */
    protected $with = [
        'address',
    ];

    public function events(): BelongsToMany
    {
        return $this
            ->belongsToMany(Event::class)
            ->using(EventVenue::class)
            ->withPivot(['id'])
            ->withTimestamps();
    }

    public function address(): MorphOne
    {
        return $this->morphOne(Address::class, 'addressable');
    }
}
