<?php

namespace EventPortal\Tests\Support\Factories;

use EventPortal\Domain\Agenda\Models\Agenda;
use EventPortal\Domain\Agenda\Models\Pathway;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Models\EventDelegate;

class PathwayFactory
{
    /**
     * @var Pathway
     */
    private $pathway;

    /**
     * @var Agenda
     */
    private $agenda;

    public function __construct(Pathway $pathway, Agenda  $agenda)
    {
        $this->pathway = $pathway;
        $this->agenda = $agenda;
    }

    public function addDelegate(Delegate $delegate): self
    {
        $this->pathway->event->delegates()->save($delegate, [
            'status' => 'invited',
            'pathway_id' => $this->pathway->id,
        ]);

        $eventDelegates = EventDelegate::where('delegate_id', $delegate->id)
            ->where('event_id', $this->pathway->event->id)
            ->first();

        $this->pathway->eventDelegates()->save($eventDelegates);

        return $this;
    }

    public function createSession(array $data, callable $callback): Session
    {
        $session = factory(Session::class)->create($data);
        $this->pathway->sessions()->save($session);
        $this->agenda->sessions()->save($session);

        $callback(new SessionFactory($session));

        return $session;
    }
}
