<?php

namespace EventPortal\Tests\Unit\Email\Composers;

use EventPortal\Domain\Component\Button;
use EventPortal\Domain\Email\Composers\EmailSendComposer;
use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Enums\EmailType;
use EventPortal\Enums\InertiaMethod;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class EmailSendComposerTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function the_composer_generates_the_modal_content_and_buttons()
    {
        $event = factory(Event::class)->create();
        $email = EventEmail::create([
            'event_id' => $event->id,
            'type' => EmailType::invite(),
            'subject' => null,
            'reply_to_address' => null,
        ]);

        $composer = new EmailSendComposer($event, $email);
        $composer->compose();


        $expectedButtons = [
            Button::make("Send to all")
                ->method(InertiaMethod::POST())
                ->route('admin.email.send', [
                    'event' => $event->id,
                    'email' => $email->id,
                ]),
        ];
        $expectedContent = [
            "Are you sure you want to send the Invite email?",
        ];

        $this->assertEquals($expectedButtons, $composer->buttons);
        $this->assertEquals($expectedContent, $composer->content);
    }
}
